@@ -6,26 +6,23 @@
 #include "DbConnection.h"
 #include "integer64.h"
 
-
-
 // Construction ////////////////////////////////////////////////////////////////
 
-SqliteResultImpl::SqliteResultImpl(const DbConnectionPtr& conn_, const std::string& sql) :
-  conn(conn_->conn()),
-  stmt(prepare(conn, sql)),
-  cache(stmt),
-  complete_(false),
-  ready_(false),
-  nrows_(0),
-  total_changes_start_(sqlite3_total_changes(conn)),
-  group_(0),
-  groups_(0),
-  types_(get_initial_field_types(cache.ncols_)),
-  with_alt_types_(conn_->with_alt_types())
-{
-
-  LOG_DEBUG << sql;
-
+SqliteResultImpl::SqliteResultImpl(
+  const DbConnectionPtr& conn_,
+  const std::string& sql
+)
+    : conn(conn_->conn()),
+      stmt(prepare(conn, sql)),
+      cache(stmt),
+      complete_(false),
+      ready_(false),
+      nrows_(0),
+      total_changes_start_(sqlite3_total_changes(conn)),
+      group_(0),
+      groups_(0),
+      types_(get_initial_field_types(cache.ncols_)),
+      with_alt_types_(conn_->with_alt_types()) {
   try {
     if (cache.nparams_ == 0) {
       after_bind(true);
@@ -38,25 +35,21 @@ SqliteResultImpl::SqliteResultImpl(const DbConnectionPtr& conn_, const std::stri
 }
 
 SqliteResultImpl::~SqliteResultImpl() {
-  LOG_VERBOSE;
-
   try {
     sqlite3_finalize(stmt);
   } catch (...) {}
 }
 
-
-
 // Cache ///////////////////////////////////////////////////////////////////////
 
 SqliteResultImpl::_cache::_cache(sqlite3_stmt* stmt)
-  : names_(get_column_names(stmt)),
-    ncols_(names_.size()),
-    nparams_(sqlite3_bind_parameter_count(stmt))
-{
-}
+    : names_(get_column_names(stmt)),
+      ncols_(names_.size()),
+      nparams_(sqlite3_bind_parameter_count(stmt)) {}
 
-std::vector<std::string> SqliteResultImpl::_cache::get_column_names(sqlite3_stmt* stmt) {
+std::vector<std::string> SqliteResultImpl::_cache::get_column_names(
+  sqlite3_stmt* stmt
+) {
   int ncols = sqlite3_column_count(stmt);
 
   std::vector<std::string> names;
@@ -70,7 +63,9 @@ std::vector<std::string> SqliteResultImpl::_cache::get_column_names(sqlite3_stmt
 // We guess the correct R type for each column from the declared column type,
 // if possible.  The type of the column can be amended as new values come in,
 // but will be fixed after the first call to fetch().
-std::vector<DATA_TYPE> SqliteResultImpl::get_initial_field_types(const size_t ncols) {
+std::vector<DATA_TYPE> SqliteResultImpl::get_initial_field_types(
+  const size_t ncols
+) {
   std::vector<DATA_TYPE> types(ncols);
   std::fill(types.begin(), types.end(), DT_UNKNOWN);
   return types;
@@ -81,16 +76,20 @@ sqlite3_stmt* SqliteResultImpl::prepare(sqlite3* conn, const std::string& sql) {
 
   const char* tail = NULL;
 
-  int rc =
-    sqlite3_prepare_v2(
-      conn, sql.c_str(), (int)std::min(sql.size() + 1, (size_t)INT_MAX),
-      &stmt, &tail
-    );
+  int rc = sqlite3_prepare_v2(
+    conn,
+    sql.c_str(),
+    (int)std::min(sql.size() + 1, (size_t)INT_MAX),
+    &stmt,
+    &tail
+  );
   if (rc != SQLITE_OK) {
     raise_sqlite_exception(conn);
   }
   if (tail) {
-    while (isspace(*tail)) ++tail;
+    while (isspace(*tail)) {
+      ++tail;
+    }
     if (*tail) {
       cpp11::warning(std::string("Ignoring remaining part of query: ") + tail);
     }
@@ -105,12 +104,9 @@ void SqliteResultImpl::init(bool params_have_rows) {
   complete_ = !params_have_rows;
 }
 
-
-
 // Publics /////////////////////////////////////////////////////////////////////
 
-void SqliteResultImpl::close() {
-}
+void SqliteResultImpl::close() {}
 
 bool SqliteResultImpl::complete() const {
   return complete_;
@@ -121,7 +117,9 @@ int SqliteResultImpl::n_rows_fetched() {
 }
 
 int SqliteResultImpl::n_rows_affected() {
-  if (!ready_) return NA_INTEGER;
+  if (!ready_) {
+    return NA_INTEGER;
+  }
   return sqlite3_total_changes(conn) - total_changes_start_;
 }
 
@@ -131,8 +129,11 @@ void SqliteResultImpl::bind(const cpp11::list& params) {
   }
 
   if (params.size() != cache.nparams_) {
-    cpp11::stop("Query requires %i params; %i supplied.",
-         cache.nparams_, params.size());
+    cpp11::stop(
+      "Query requires %i params; %i supplied.",
+      cache.nparams_,
+      params.size()
+    );
   }
 
   set_params(params);
@@ -148,17 +149,18 @@ void SqliteResultImpl::bind(const cpp11::list& params) {
 }
 
 cpp11::list SqliteResultImpl::fetch(const int n_max) {
-  if (!ready_)
+  if (!ready_) {
     cpp11::stop("Query needs to be bound before fetching");
+  }
 
   int n = 0;
   cpp11::list out;
 
   if (n_max != 0) {
     out = fetch_rows(n_max, n);
-  }
-  else
+  } else {
     out = peek_first_row();
+  }
 
   return out;
 }
@@ -169,12 +171,13 @@ cpp11::list SqliteResultImpl::get_column_info() {
 
   cpp11::writable::strings names(cache.names_.size());
   auto it = cache.names_.begin();
-  for (int i = 0; i < names.size(); i++, it++)
+  for (int i = 0; i < names.size(); i++, it++) {
     names[i] = *it;
+  }
 
   cpp11::writable::strings types(cache.ncols_);
   for (size_t i = 0; i < cache.ncols_; i++) {
-    switch(types_[i]) {
+    switch (types_[i]) {
     case DT_DATE:
       types[i] = "Date";
       break;
@@ -185,16 +188,15 @@ cpp11::list SqliteResultImpl::get_column_info() {
       types[i] = "hms";
       break;
     default:
-      types[i] = Rf_type2char(DbColumnStorage::sexptype_from_datatype(types_[i]));
+      types[i] =
+        Rf_type2char(DbColumnStorage::sexptype_from_datatype(types_[i]));
       break;
     }
   }
 
-  return cpp11::list({"name"_nm = names, "type"_nm = types});
+  return cpp11::list({ "name"_nm = names, "type"_nm = types });
 }
 
-
-
 // Publics (custom) ////////////////////////////////////////////////////////////
 
 cpp11::strings SqliteResultImpl::get_placeholder_names() const {
@@ -204,18 +206,17 @@ cpp11::strings SqliteResultImpl::get_placeholder_names() const {
 
   for (int i = 0; i < n; ++i) {
     const char* placeholder_name = sqlite3_bind_parameter_name(stmt, i + 1);
-    if (placeholder_name == NULL)
+    if (placeholder_name == NULL) {
       placeholder_name = "";
-    else
+    } else {
       ++placeholder_name;
+    }
     res[i] = placeholder_name;
   }
 
   return res;
 }
 
-
-
 // Privates ////////////////////////////////////////////////////////////////////
 
 void SqliteResultImpl::set_params(const cpp11::list& params) {
@@ -223,10 +224,9 @@ void SqliteResultImpl::set_params(const cpp11::list& params) {
 }
 
 bool SqliteResultImpl::bind_row() {
-  LOG_VERBOSE << "groups: " << group_ << "/" << groups_;
-
-  if (group_ >= groups_)
+  if (group_ >= groups_) {
     return false;
+  }
 
   sqlite3_reset(stmt);
   sqlite3_clear_bindings(stmt);
@@ -240,8 +240,6 @@ bool SqliteResultImpl::bind_row() {
 }
 
 void SqliteResultImpl::bind_parameter_pos(int j, SEXP value_) {
-  LOG_VERBOSE << "TYPEOF(value_): " << TYPEOF(value_);
-
   if (TYPEOF(value_) == LGLSXP) {
     int value = LOGICAL(value_)[group_];
     if (value == NA_LOGICAL) {
@@ -249,61 +247,62 @@ void SqliteResultImpl::bind_parameter_pos(int j, SEXP value_) {
     } else {
       sqlite3_bind_int(stmt, j, value);
     }
-  }
-  else if (TYPEOF(value_) == INT64SXP && Rf_inherits(value_, "integer64")) {
+  } else if (TYPEOF(value_) == INT64SXP && Rf_inherits(value_, "integer64")) {
     int64_t value = INTEGER64(value_)[group_];
     if (value == NA_INTEGER64) {
       sqlite3_bind_null(stmt, j);
     } else {
       sqlite3_bind_int64(stmt, j, value);
     }
-  }
-  else if (TYPEOF(value_) == INTSXP) {
+  } else if (TYPEOF(value_) == INTSXP) {
     int value = INTEGER(value_)[group_];
     if (value == NA_INTEGER) {
       sqlite3_bind_null(stmt, j);
     } else {
       sqlite3_bind_int(stmt, j, value);
     }
-  }
-  else if (TYPEOF(value_) == REALSXP) {
+  } else if (TYPEOF(value_) == REALSXP) {
     double value = REAL(value_)[group_];
     if (value == NA_REAL) {
       sqlite3_bind_null(stmt, j);
     } else {
       sqlite3_bind_double(stmt, j, value);
     }
-  }
-  else if (TYPEOF(value_) == STRSXP) {
+  } else if (TYPEOF(value_) == STRSXP) {
     SEXP value = STRING_ELT(value_, group_);
     if (value == NA_STRING) {
       sqlite3_bind_null(stmt, j);
     } else {
       sqlite3_bind_text(stmt, j, CHAR(value), -1, SQLITE_TRANSIENT);
     }
-  }
-  else if (TYPEOF(value_) == VECSXP) {
+  } else if (TYPEOF(value_) == VECSXP) {
     SEXP value = VECTOR_ELT(value_, group_);
     if (TYPEOF(value) == NILSXP) {
       sqlite3_bind_null(stmt, j);
-    }
-    else if (TYPEOF(value) == RAWSXP) {
-      sqlite3_bind_blob(stmt, j, RAW(value), Rf_length(value), SQLITE_TRANSIENT);
-    }
-    else {
+    } else if (TYPEOF(value) == RAWSXP) {
+      sqlite3_bind_blob(
+        stmt,
+        j,
+        RAW(value),
+        Rf_length(value),
+        SQLITE_TRANSIENT
+      );
+    } else {
       cpp11::stop("Can only bind lists of raw vectors (or NULL)");
     }
-  }
-  else {
-    cpp11::stop("Don't know how to handle parameter of type %s.",
-         Rf_type2char(TYPEOF(value_)));
+  } else {
+    cpp11::stop(
+      "Don't know how to handle parameter of type %s.",
+      Rf_type2char(TYPEOF(value_))
+    );
   }
 }
 
 void SqliteResultImpl::after_bind(bool params_have_rows) {
   init(params_have_rows);
-  if (params_have_rows)
+  if (params_have_rows) {
     step();
+  }
 }
 
 cpp11::list SqliteResultImpl::fetch_rows(const int n_max, int& n) {
@@ -312,21 +311,22 @@ cpp11::list SqliteResultImpl::fetch_rows(const int n_max, int& n) {
   SqliteDataFrame data(stmt, cache.names_, n_max, types_, with_alt_types_);
 
   if (complete_ && data.get_ncols() == 0) {
-    Rf_warning("SQL statements must be issued with dbExecute() or dbSendStatement() instead of dbGetQuery() or dbSendQuery().");
+    Rf_warning(
+      "`dbGetQuery()`, `dbSendQuery()` and `dbFetch()` should only be used "
+      "with `SELECT` queries. Did you mean `dbExecute()`, `dbSendStatement()` "
+      "or `dbGetRowsAffected()`?"
+    );
   }
 
   while (!complete_) {
-    LOG_VERBOSE << nrows_ << "/" << n;
-
     data.set_col_values();
     step();
     nrows_++;
-    if (!data.advance())
+    if (!data.advance()) {
       break;
+    }
   }
 
-  LOG_VERBOSE << nrows_;
-
   return data.get_data(types_);
 }
 
@@ -336,8 +336,6 @@ void SqliteResultImpl::step() {
 }
 
 bool SqliteResultImpl::step_run() {
-  LOG_VERBOSE;
-
   int rc = sqlite3_step(stmt);
 
   switch (rc) {
@@ -354,18 +352,19 @@ bool SqliteResultImpl::step_done() {
   ++group_;
   bool more_params = bind_row();
 
-  if (!more_params)
+  if (!more_params) {
     complete_ = true;
+  }
 
-  LOG_VERBOSE << "group: " << group_ << ", more_params: " << more_params;
   return more_params;
 }
 
 cpp11::list SqliteResultImpl::peek_first_row() {
   SqliteDataFrame data(stmt, cache.names_, 1, types_, with_alt_types_);
 
-  if (!complete_)
+  if (!complete_) {
     data.set_col_values();
+  }
   // Not calling data.advance(), remains a zero-row data frame
 
   return data.get_data(types_);
